diff --git a/src/locales/en-US/clusters.ts b/src/locales/en-US/clusters.ts
index b409abe8..80162a0a 100644
--- a/src/locales/en-US/clusters.ts
+++ b/src/locales/en-US/clusters.ts
@@ -132,5 +132,7 @@ export default {
'clusters.addworker.theadNotes':
'If the /usr/local/PPU_SDK directory does not exist, please create a symbolic link pointing to the T-Head PPU SDK installed path: ln -s /path/to/PPU_SDK /usr/local/PPU_SDK.',
'clusters.addworker.theadNotes-02':
- 'T-Head PPU uses the Container Device Interface (CDI) for device injection and requires the /var/run/cdi directory to be available for CDI generation.'
+ 'T-Head PPU uses the Container Device Interface (CDI) for device injection and requires the /var/run/cdi directory to be available for CDI generation.',
+ 'clusters.addworker.nvidiaNotes':
+ 'The built-in inference backends in GPUStack v2.1 require CUDA 12.6+. Please ensure your NVIDIA driver version is 560 or newer.'
};
diff --git a/src/locales/ru-RU/clusters.ts b/src/locales/ru-RU/clusters.ts
index c82e1953..10165594 100644
--- a/src/locales/ru-RU/clusters.ts
+++ b/src/locales/ru-RU/clusters.ts
@@ -133,7 +133,9 @@ export default {
'clusters.addworker.theadNotes':
'If the ln -s /path/to/PPU_SDK /usr/local/PPU_SDK',
'clusters.addworker.theadNotes-02':
- 'T-Head PPU uses the Container Device Interface (CDI) for device injection and requires the /var/run/cdi directory to be available for CDI generation.'
+ 'T-Head PPU uses the Container Device Interface (CDI) for device injection and requires the /var/run/cdi directory to be available for CDI generation.',
+ 'clusters.addworker.nvidiaNotes':
+ 'The built-in inference backends in GPUStack v2.1 require CUDA 12.6+. Please ensure your NVIDIA driver version is 560 or newer.'
};
// ========== To-Do: Translate Keys (Remove After Translation) ==========
@@ -149,4 +151,5 @@ export default {
// 10. 'clusters.addworker.theadNotes': 'If the ln -s /path/to/PPU_SDK /usr/local/PPU_SDK',
// 11. 'clusters.addworker.theadNotes-02': 'T-Head PPU uses the Container Device Interface (CDI) for device injection and requires the /var/run/cdi directory to be available for CDI generation.'
// 12. 'clusters.addworker.metaxNotes': `If the /opt/mxdriver or /opt/maca directory does not exist, create a symbolic link to the MetaX driver and SDK installation path: ln -s /path/to/mxdriver /opt/mxdriverln -s /path/to/maca /opt/maca.`,
+// 13. 'clusters.addworker.nvidiaNotes': 'The built-in inference backends in GPUStack v2.1 require CUDA 12.6+. Please ensure your NVIDIA driver version is 560 or newer.'
// ================================================================
diff --git a/src/locales/zh-CN/clusters.ts b/src/locales/zh-CN/clusters.ts
index 6f489c4c..ef0bb7ce 100644
--- a/src/locales/zh-CN/clusters.ts
+++ b/src/locales/zh-CN/clusters.ts
@@ -126,5 +126,7 @@ export default {
'clusters.addworker.theadNotes':
'如果 /usr/local/PPU_SDK 目录不存在,请创建一个指向已安装平头哥(T-Head)PPU SDK 路径的符号链接:ln -s /path/to/PPU_SDK /usr/local/PPU_SDK。',
'clusters.addworker.theadNotes-02':
- '平头哥(T-Head)PPU 使用容器设备接口(CDI)进行设备注入,因此需要确保 /var/run/cdi 目录可用以生成 CDI。'
+ '平头哥(T-Head)PPU 使用容器设备接口(CDI)进行设备注入,因此需要确保 /var/run/cdi 目录可用以生成 CDI。',
+ 'clusters.addworker.nvidiaNotes':
+ 'GPUStack v2.1 内置推理后端依赖 CUDA 12.6 及以上版本,请确保 NVIDIA 驱动版本为 560 或以上。'
};
diff --git a/src/pages/resources/config/gpu-driver.ts b/src/pages/resources/config/gpu-driver.ts
index 5a3b91f8..75e101a1 100644
--- a/src/pages/resources/config/gpu-driver.ts
+++ b/src/pages/resources/config/gpu-driver.ts
@@ -343,7 +343,7 @@ export const registerAddWokerCommandMap = {
};
export const AddWorkerDockerNotes: Record = {
- [GPUDriverMap.NVIDIA]: [],
+ [GPUDriverMap.NVIDIA]: ['clusters.addworker.nvidiaNotes'],
[GPUDriverMap.AMD]: ['clusters.addworker.amdNotes-01'],
[GPUDriverMap.MOORE_THREADS]: [],
[GPUDriverMap.ASCEND]: [],
diff --git a/src/locales/ja-JP/clusters.ts b/src/locales/ja-JP/clusters.ts
index 12004feb..b0468741 100644
--- a/src/locales/ja-JP/clusters.ts
+++ b/src/locales/ja-JP/clusters.ts
@@ -132,7 +132,9 @@ export default {
'clusters.addworker.theadNotes':
'If the ln -s /path/to/PPU_SDK /usr/local/PPU_SDK',
'clusters.addworker.theadNotes-02':
- 'T-Head PPU uses the Container Device Interface (CDI) for device injection and requires the /var/run/cdi directory to be available for CDI generation.'
+ 'T-Head PPU uses the Container Device Interface (CDI) for device injection and requires the /var/run/cdi directory to be available for CDI generation.',
+ 'clusters.addworker.nvidiaNotes':
+ 'The built-in inference backends in GPUStack v2.1 require CUDA 12.6+. Please ensure your NVIDIA driver version is 560 or newer.'
};
// ========== To-Do: Translate Keys (Remove After Translation) ==========
@@ -235,5 +237,6 @@ export default {
// 93. 'clusters.create.k8sTips2': 'You can also skip this step and register it later from the cluster list.',
// 94. 'clusters.create.steps.configure': 'Configure',
// 99. 'clusters.addworker.theadNotes': 'If the ln -s /path/to/PPU_SDK /usr/local/PPU_SDK',
// 100. 'clusters.addworker.theadNotes-02': 'T-Head PPU uses the Container Device Interface (CDI) for device injection and requires the /var/run/cdi directory to be available for CDI generation.'
// ========== End of To-Do List ==========
@@ -235,5 +237,6 @@ export default {
// 94. 'clusters.create.steps.configure': 'Configure',
// 99. 'clusters.addworker.theadNotes': 'If the ln -s /path/to/PPU_SDK /usr/local/PPU_SDK',
-// 100. 'clusters.addworker.theadNotes-02': 'T-Head PPU uses the Container Device Interface (CDI) for device injection and requires the /var/run/cdi directory to be available for CDI generation.'
+// 100. 'clusters.addworker.theadNotes-02': 'T-Head PPU uses the Container Device Interface (CDI) for device injection and requires the /var/run/cdi directory to be available for CDI generation.',
+// 101. 'clusters.addworker.nvidiaNotes': 'The built-in inference backends in GPUStack v2.1 require CUDA 12.6+. Please ensure your NVIDIA driver version is 560 or newer.'
// ========== End of To-Do List ==========